#
# spec file for package switchboard-plug-network
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.settings.network
Name:           switchboard-plug-network
Version:        8.1.0
Release:        1.2
Summary:        Switchboard Network Plug
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/switchboard-plug-network
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(libnma)
BuildRequires:  pkgconfig(libnma-gtk4)
BuildRequires:  pkgconfig(switchboard-3)
BuildRequires:  pkgconfig(vapigen)
Requires:       switchboard

%description
Configure all available networks.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%fdupes %{buildroot}%{_datadir}
%find_lang %{appid}

%files
%license COPYING
%doc README.md
%dir %{_libdir}/{switchboard-3,switchboard-3/network}
%{_libdir}/switchboard-3/network/libnetwork.so
%{_datadir}/metainfo/%{appid}.metainfo.xml

%files lang -f %{appid}.lang

%changelog
* Fri Feb 14 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 8.1.0:
  * InfoBox: add metered data switch
  * Update translation template
  * WifiPage: create settings dialog
  * WifiMenuItem: manage own button box
  * InfoBox: add auto connect switch
  * WifiPage: update listbox with list model
  * Revert "WifiPage: update listbox with list model
  * InfoBox: remove extra margins and align
* Tue Nov 12 2024 Richard Rahl <rrahl0@opensuse.org>
- Require switchboard at runtime
* Thu Oct 24 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.1:
  * Automatically select active network when opening
  * Restore sidebar position
  * Updated translations
* Fri Aug  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Provide description text on the VPN page
  * Show connected Wi-Fi network name in sidebar
  * Updated translations
- update to 2.5.0:
  * WireGuard support
  * OWE support
  * Updated translations
- update to 2.4.4:
  * Updated translations
- update to 2.4.3:
  * Show correct info for WPA3 networks
  * Updated translations
- update to 2.4.2:
  * Fix an issue with wired connections repeatedly reconnecting
  * Updated translations
- update to 2.4.1:
  * Fix a crash on startup for some devices
  * Updated translations
- update to 2.4.0:
  * Show message when Ethernet is unplugged
  * Show DNS info
  * Updated translations
- update to 2.3.3:
  * Better status when wireless network is disabled
  * Updated translations
- update to 2.3.2:
  * Updated translations
- update to 2.3.1:
  * Better support for various network encryption types
  * More accurately report encryption type
  * Updated translations
- update to 2.3.0:
  * Redesigned Wireless page
  * Updated translations
- switch url to github, as we don't want to link to a different OS
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.2.0:
  * WifiMenuItem: Clean up properties (#222)
  * Add Gettext Updates to Actions
  * Granite.Services.Settings → GLib.Settings (#207)
  * VPNInfoDialog: DRY get_service_type (#216)
  * Remove unused libnm.vapi (#215)
  * Add Release to Actions
  * Remove deb packaging from master (#214)
  * VPN Panel Redesign (#208)
  * run installation in CI (#205)
  * Add Lint to CI (#202)
  * lint src files via vala-lint (#203)
  * README: Fix weblate badge
  * Delete AUTHORS
  * Test With GitHub CI (#200)
  * Delete CODE_OF_CONDUCT.md
  * Delete FUNDING.yml
  * HotspotPage: handle hotspot creation in page (#176)
  * build: fix install path for switchboard plug (#192)
  * DeviceItem: More GObject-style (#189)
  * Update Plug.vala
  * Remove WidgetNMInterface (#188)
  * DeviceItem: Get icon name from Page when possible (#190)
  * Merge remote-tracking branch 'weblate/master'
  * WifiMenuItem: simplify hide/show spinner (#174)
  * Create FUNDING.yml
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.4:
  * New upstream release.
* Thu Nov  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add regex for filtering provided libraries
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.3:
  * New upstream release.
* Mon Jun 11 2018 avvissu@yandex.by
- Update to 0.1.2:
  * New upstream release.
* Sat Jun  9 2018 avvissu@yandex.by
- Rename to switchboard-plug-network
- Switch to github
- Switch to meson
- Add COPYING and README files
- Spec file cleanup
* Mon Nov 13 2017 avvissu@yandex.by
- Add NetworkManager-{openvpn,pptp,vpnc} as recommended dependency
* Mon Sep 18 2017 avvissu@yandex.by
- Update to 0.1.1:
  * Add Repology and Weblate badges to README.md (#63)
  * Delete old files (#62)
  * Create README.md (#61)
  * Create CODE_OF_CONDUCT.md (#60)
* Fri Nov 25 2016 avvissu@yandex.by
- Update to 0.1.0.3:
  * cmake: specify C project
  * Updated translation template
  * Update proxy layout
  * Fix for not showing the current proxy configuration
  * Remove polkit-gobject-1 references since it isn't used
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 0.1.0.2
- Add Requires: NetworkManager-gnome, NetworkManager-connection-editor
- Spec file cleanup
* Sun Feb 28 2016 mailaender@opensuse.org
- initial packaging (version 0.1+r215) for build.opensuse.org
